addpath('support')
addpath('quasirandom_sequences')
addpath('monte_carlo_integration')
addpath('plot_generators')

function [y] = integrand(x)
    y = x(1)^2 * x(3);
end

global a = [0 0 0];
global b = [1 2*pi 4];
exact_result = 16 * pi/3;
n_range = 2^7:2^7:2^12;

mcm_methods = struct(
    'name', {
        'Naive MCM'
        'Symmetric MCM'
        'Stratified MCM with K=2'
        'Stratified MCM with K=4'
    },

    'evaluate', {
        @(n) naive_mcm(@integrand, a, b, n)
        @(n) symmetric_mcm(@integrand, a, b, n)
        @(n) stratified_mcm(@integrand, a, b, n, 2)
        @(n) stratified_mcm(@integrand, a, b, n, 4)
    }
);

qr_sequences = struct(
    'name', {
        'Halton sequence'
        'Hammersley point set'
        'Sobol sequence'
        'Faure sequence'
    },

    'generator', {
        @halton_sequence
        @hammersley_point_set
        @sobol_sequence
        @faure_sequence
    }
);

graphics_toolkit('gnuplot')

% % Plots for the individual MCM errors
for i = 1:length(mcm_methods)
    benchmark_mcm_methods(n_range, exact_result, mcm_methods(i), strcat('plots/mcm_', num2str(i)));
end

% % Cumulative plot for the MCM errors
benchmark_mcm_methods(n_range, exact_result, mcm_methods, 'plots/mcm_all');

% % Plots for the quasirandom sequences
for i = 1:length(qr_sequences)
    plot_quasirandom_sequence(qr_sequences(i), strcat('plots/seq_', num2str(i)));
end

% % Plots for the individual quasi MCM errors
for i = 1:length(qr_sequences)
    benchmark_qmcm_sequences(n_range, exact_result, qr_sequences(i), strcat('plots/qmcm_', num2str(i)));
end

% Cumulative plot for the quasi MCM errors
benchmark_qmcm_sequences(n_range, exact_result, qr_sequences, 'plots/qmcm_all');

% Cumulative plot for the Hammersley and Sobol sequences in an "interesting" spot
benchmark_qmcm_sequences([3000:100:3500], exact_result, qr_sequences(2:3), 'plots/qmcm_2,3');
